Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Message ¶
type Message interface {
Name() string
//Template return tmpl string which used to build template
//instance. due to go do not support struct statis property
//is not easy to impl a method which return template instance
Template() string
}
Message a text temlpate message instance which send to location
Click to show internal directories.
Click to hide internal directories.